add quiet mode flag for cli
[project/uci.git] / uci.h
diff --git a/uci.h b/uci.h
index 93f8bce..e921269 100644 (file)
--- a/uci.h
+++ b/uci.h
@@ -105,6 +105,7 @@ extern void uci_perror(struct uci_context *ctx, const char *str);
  * @single: ignore the 'package' keyword and parse everything into a single package
  *
  * the name parameter is for config files that don't explicitly use the 'package <...>' keyword
+ * if 'package' points to a non-null struct pointer, enable history tracking and merge 
  */
 extern int uci_import(struct uci_context *ctx, FILE *stream, const char *name, struct uci_package **package, bool single);
 
@@ -213,11 +214,12 @@ extern int uci_save(struct uci_context *ctx, struct uci_package *p);
  * uci_commit: commit changes to a package
  * @ctx: uci context
  * @p: uci_package struct pointer
+ * @overwrite: overwrite existing config data and flush history
  *
  * committing may reload the whole uci_package data,
  * the supplied pointer is updated accordingly
  */
-extern int uci_commit(struct uci_context *ctx, struct uci_package **p);
+extern int uci_commit(struct uci_context *ctx, struct uci_package **p, bool overwrite);
 
 /**
  * uci_list_configs: List available uci config files
@@ -235,8 +237,9 @@ enum uci_type {
 };
 
 enum uci_flags {
-       UCI_FLAG_STRICT = (1 << 0), /* strict mode for the parser */
-       UCI_FLAG_PERROR = (1 << 1), /* print error messages to stderr */
+       UCI_FLAG_STRICT =      (1 << 0), /* strict mode for the parser */
+       UCI_FLAG_PERROR =      (1 << 1), /* print parser error messages */
+       UCI_FLAG_EXPORT_NAME = (1 << 2), /* when exporting, name unnamed sections */
 };
 
 struct uci_element
@@ -276,6 +279,7 @@ struct uci_parse_context
        /* private: */
        struct uci_package *package;
        struct uci_section *section;
+       bool merge;
        FILE *file;
        const char *name;
        char *buf;